@@ -15,7 +15,7 @@
 //
 // You should have received a copy of the GNU General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 /** \file
     \brief MarchingCubes Algorithm
@@ -27,8 +27,8 @@
 
 // Minor modifications for KDE-Edu/Analitza Library: Copyright (C) 2014 by Percy Camilo T. Aucahuasi <percy.camilo.ta@gmail.com>
 
-#ifndef FUNCTIONGRAPH2_H_mcub
-#define FUNCTIONGRAPH2_H_mcub
+#ifndef MARCHINGCUBES_H
+#define MARCHINGCUBES_H
 
 #include <QVector>
 
@@ -118,9 +118,9 @@ public :
   /** accesses the number of triangles of the generated mesh */
   int ntrigs() const { return i_ntrigs ; }
   /** accesses a specific vertex of the generated mesh */
-  Vertex   * vert( const int i ) const { if( i < 0  || i >= i_nverts ) return ( Vertex *)NULL ; return i_vertices  + i ; }
+  Vertex   * vert( const int i ) const { if( i < 0  || i >= i_nverts ) return ( Vertex *)nullptr ; return i_vertices  + i ; }
   /** accesses a specific triangle of the generated mesh */
-  Triangle * trig( const int i ) const { if( i < 0  || i >= i_ntrigs ) return (Triangle*)NULL ; return i_triangles + i ; }
+  Triangle * trig( const int i ) const { if( i < 0  || i >= i_ntrigs ) return (Triangle*)nullptr ; return i_triangles + i ; }
 
   /** accesses the vertex buffer of the generated mesh */
   Vertex   *mc_vertices () { return i_vertices  ; }
