@@ -164,11 +164,7 @@ void PlotsView2D::wheelEvent(QWheelEvent *e)
     qreal d = (-0.03*steps) + 1;
     
     if(d>0 || (viewport.width()+d > 2 && viewport.height()+d < 2)) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-        scaleViewport(d, e->pos());
-#else
         scaleViewport(d, e->position().toPoint());
-#endif
     }
 }
 
